@@ -110,8 +110,8 @@ enum HistEntFlagBits
 
 typedef struct VectorEnt
 {
-vptr next;
 TimeType time;
+vptr next;
 unsigned char v[1];
 } VectorEnt;
 
@@ -285,6 +285,7 @@ typedef struct
 
     Trptr    scroll_top;	/* for autoscrolling */
     Trptr    scroll_bottom;
+    unsigned dirty : 1;		/* to notify Tcl that traces were added/deleted/moved */
   } Traces;
 
 
@@ -441,14 +442,20 @@ char*    GetFullName(Trptr t);
 
 void OpenTrace(Trptr t);
 void CloseTrace(Trptr t);
-void ClearTraces();
+void ClearTraces(void);
 void ClearGroupTraces(Trptr t);
 
 #endif
 
 /*
- * $Id: analyzer.h,v 1.28 2010/04/07 01:50:45 gtkwave Exp $
+ * $Id: analyzer.h,v 1.30 2010/09/10 05:58:40 gtkwave Exp $
  * $Log: analyzer.h,v $
+ * Revision 1.30  2010/09/10 05:58:40  gtkwave
+ * structor reordering of VectorEnt to benefit 32-bit architectures
+ *
+ * Revision 1.29  2010/08/02 20:44:35  gtkwave
+ * added gtkwave::cbTracesUpdated
+ *
  * Revision 1.28  2010/04/07 01:50:45  gtkwave
  * improved name handling for bvname, add $next transaction operation
  *
