@@ -68,12 +68,12 @@ while(*p1 && *p2)
 
 		if(!pfx) return(NULL);
 
-		if(isdigit(*p1)&&isdigit(*p2))
+		if(isdigit((int)(unsigned char)*p1)&&isdigit((int)(unsigned char)*p2))
 			{
 			n1 = p1; n2 = p2;
 			while(*p1)
 				{
-				if(isdigit(*p1))
+				if(isdigit((int)(unsigned char)*p1))
 					{
 					n1len++;
 					}
@@ -86,7 +86,7 @@ while(*p1 && *p2)
 
 			while(*p2)
 				{
-				if(isdigit(*p2))
+				if(isdigit((int)(unsigned char)*p2))
 					{
 					n2len++;
 					}
@@ -132,7 +132,7 @@ if((*p1)||(*p2)) return(NULL);
 
 while(pfxlen>1)	/* backup if matching a sequence like 20..24 where the 2 matches outside of the left bracket */
 	{
-	if(isdigit(s1[pfxlen-1]))
+	if(isdigit((int)(unsigned char)s1[pfxlen-1]))
 		{
 		pfxlen--;
 		n1--; n1len++;
@@ -468,7 +468,7 @@ len=0;
 while(1)
 	{
 	ch=*pnt++;
-	if(isspace(ch)||(!ch)) break;
+	if(isspace((int)(unsigned char)ch)||(!ch)) break;
 	len++;
 	}
 
@@ -519,7 +519,7 @@ len=0;
 while(1)
 	{
 	ch=*pnt++;
-	if(isspace(ch)||(!ch)) break;
+	if(isspace((int)(unsigned char)ch)||(!ch)) break;
 	len++;
 	}
 
@@ -565,6 +565,53 @@ if(len)
 							if(nodepnt==BITATTRIBUTES_MAX) { free_2(wild); goto ifnode; }
 							}		
 						}
+					else
+                                              	{
+                                                char *lp = strrchr(wild+i, '[');
+                                                if(lp)
+                                                        {
+                                                        char *ns = malloc_2(strlen(wild+i) + 32);
+                                                        char *colon = strchr(lp+1, ':');
+                                                        int msi, lsi, bval, actual;
+                                                        *lp = 0;
+
+                                                        bval = atoi(wild+1);
+                                                        if(colon)
+                                                                {
+                                                                msi = atoi(lp+1);
+                                                                lsi = atoi(colon+1);
+
+                                                                if(lsi > msi)
+                                                                        {
+                                                                        actual = msi + bval;
+                                                                        }
+                                                                        else
+                                                                        {
+                                                                        actual = msi - bval;
+                                                                        }
+                                                                }
+                                                                else
+                                                                {
+                                                                actual = bval; /* punt */
+                                                                }
+
+                                                        sprintf(ns, "%s[%d]", wild+i, actual); 
+                                                        *lp = '[';
+
+                                                        s=symfind(ns, &rows);
+                                                        if(s)
+                                                                {
+								nexp =&s->n[rows];
+								if(nexp)
+									{
+									n[nodepnt++]=nexp;
+									if(nodepnt==BITATTRIBUTES_MAX) { free_2(wild); goto ifnode; }
+									}
+                                                                }
+
+							free_2(ns);
+                                                        }
+						}
 					break;
 					}
 				}
@@ -639,7 +686,7 @@ len=0;
 while(1)
 	{
 	ch=*pnt++;
-	if(isspace(ch)||(!ch)) break;
+	if(isspace((int)(unsigned char)ch)||(!ch)) break;
 	len++;
 	}
 
@@ -692,6 +739,54 @@ if(len)
 							if(nodepnt==BITATTRIBUTES_MAX) { free_2(wild); goto ifnode; }
 							}		
 						}
+					else
+                                              	{
+                                                char *lp = strrchr(wild+i, '[');
+                                                if(lp)
+                                                        {
+                                                        char *ns = malloc_2(strlen(wild+i) + 32);
+                                                        char *colon = strchr(lp+1, ':');
+                                                        int msi, lsi, bval, actual;
+                                                        *lp = 0;
+
+                                                        bval = atoi(wild+1);
+                                                        if(colon)
+                                                                {
+                                                                msi = atoi(lp+1);
+                                                                lsi = atoi(colon+1);
+
+                                                                if(lsi > msi)
+                                                                        {
+                                                                        actual = msi + bval;
+                                                                        }
+                                                                        else
+                                                                        {
+                                                                        actual = msi - bval;
+                                                                        }
+                                                                }
+                                                                else
+                                                                {
+                                                                actual = bval; /* punt */
+                                                                }
+
+                                                        sprintf(ns, "%s[%d]", wild+i, actual); 
+                                                        *lp = '[';
+
+                                                        s=symfind(ns, &rows);
+                                                        if(s)
+                                                                {
+								nexp =&s->n[rows];
+								if(nexp)
+									{
+									n[nodepnt++]=nexp;
+									if(nodepnt==BITATTRIBUTES_MAX) { free_2(wild); goto ifnode; }
+									}
+                                                                }
+
+							free_2(ns);
+                                                        }
+						}
+
 					break;
 					}
 				}
@@ -2120,7 +2215,7 @@ int parsewavline(char *w, char *alias, int depth)
 
   while(1)
     {
-      if(isspace(*w)) { w++; continue; }
+      if(isspace((int)(unsigned char)*w)) { w++; continue; }
       if(!(*w)) return(0);	/* no args */
       break;			/* start grabbing chars from here */
     }
@@ -2268,6 +2363,47 @@ if(*w2=='+')
 	      }	
 	      else 
 		{
+		char *lp = strrchr(suffix+i, '[');
+		if(lp)
+			{
+			char *ns = malloc_2(strlen(suffix+i) + 32);
+			char *colon = strchr(lp+1, ':');
+			int msi, lsi, bval, actual;
+			*lp = 0;
+
+			bval = atoi(suffix+1);
+			if(colon)
+				{
+				msi = atoi(lp+1);
+				lsi = atoi(colon+1);
+
+				if(lsi > msi)
+					{
+					actual = msi + bval;
+					}
+					else
+					{
+					actual = msi - bval;
+					}
+				}
+				else
+				{
+				actual = bval; /* punt */
+				}
+
+			sprintf(ns, "%s[%d]", suffix+i, actual);
+			*lp = '[';			
+
+			s=symfind(ns, &rows);
+			free_2(ns);
+			if(s)
+				{
+				AddNode(&s->n[rows], prefix+1);
+				return(~0);
+				}
+
+			}
+
 		  return(0);
 		}
 	    }
@@ -2307,7 +2443,7 @@ if((*w2=='#')||(*w2==':'))
 	w2=w2+strlen(prefix);
 	while(1)
 		{
-		if(isspace(*w2)) { w2++; continue; }
+		if(isspace((int)(unsigned char)*w2)) { w2++; continue; }
 		if(!(*w2)) return(0);	/* no more args */	
 		break;			/* start grabbing chars from here */
 		}
@@ -2415,13 +2551,13 @@ if(*w2=='!')
 		ch = *(w2+7);
 		if(ch != 0)
 			{
-			if (isupper(ch) || ch=='@')
+			if (isupper((int)(unsigned char)ch) || ch=='@')
 				GLOBALS->strace_ctx->shadow_mark_idx_start = ch - '@';
 		
 			ch = *(w2+8);
 			if(ch != 0)
 				{
-				if (isupper(ch) || ch=='@')
+				if (isupper((int)(unsigned char)ch) || ch=='@')
 					GLOBALS->strace_ctx->shadow_mark_idx_end = ch - '@';
 				}
 			}
@@ -2469,8 +2605,8 @@ else if(*w2=='^')
 			char *fn = w2+3;
 			if(fn)
 				{
-				while(*fn && isspace(*fn)) fn++;
-				if(*fn && !isspace(*fn)) 
+				while(*fn && isspace((int)(unsigned char)*fn)) fn++;
+				if(*fn && !isspace((int)(unsigned char)*fn)) 
 					{
 					set_current_translate_proc(fn);
 					}
@@ -2488,8 +2624,8 @@ else if(*w2=='^')
 			char *fn = w2+3;
 			if(fn)
 				{
-				while(*fn && isspace(*fn)) fn++;
-				if(*fn && !isspace(*fn)) 
+				while(*fn && isspace((int)(unsigned char)*fn)) fn++;
+				if(*fn && !isspace((int)(unsigned char)*fn)) 
 					{
 					set_current_translate_ttrans(fn);
 					}
@@ -2505,8 +2641,8 @@ else if(*w2=='^')
 			char *fn = strstr(w2+2, " ");
 			if(fn)
 				{
-				while(*fn && isspace(*fn)) fn++;
-				if(*fn && !isspace(*fn)) 
+				while(*fn && isspace((int)(unsigned char)*fn)) fn++;
+				if(*fn && !isspace((int)(unsigned char)*fn)) 
 					{
 					set_current_translate_file(fn);
 					}
@@ -2564,7 +2700,7 @@ else if (*w2 == '[')
 	{
 	while(*w)
 		{
-		if(!isspace(*w))
+		if(!isspace((int)(unsigned char)*w))
 			{
 			break;
 			}
@@ -2598,7 +2734,7 @@ else if (*w2 == '[')
 	char *pnt = w;
 	int which;
 
-	if((*pnt) && (isspace(*pnt))) pnt++;
+	if((*pnt) && (isspace((int)(unsigned char)*pnt))) pnt++;
 
 	if(*pnt)
 		{
@@ -2710,7 +2846,7 @@ len=0;
 while(1)
 	{
 	ch=*pnt++;
-	if(isspace(ch)||(!ch)) break;
+	if(isspace((int)(unsigned char)ch)||(!ch)) break;
 	len++;
 	}
 
@@ -2759,7 +2895,7 @@ len=0;
 while(1)
 	{
 	ch=*pnt++;
-	if(isspace(ch)||(!ch)) break;
+	if(isspace((int)(unsigned char)ch)||(!ch)) break;
 	len++;
 	}
 
@@ -2860,7 +2996,7 @@ int parsewavline_lx2(char *w, char *alias, int depth)
 
   while(1)
     {
-      if(isspace(*w)) { w++; continue; }
+      if(isspace((int)(unsigned char)*w)) { w++; continue; }
       if(!(*w)) return(0);	/* no args */
       break;			/* start grabbing chars from here */
     }
@@ -2957,6 +3093,49 @@ if(*w2=='+')
 			lx2_set_fac_process_mask(s->n);
 			made = ~0;
 			}
+                else
+                        {
+                        char *lp = strrchr(suffix+i, '[');
+			if(lp)
+				{
+				char *ns = malloc_2(strlen(suffix+i) + 32);
+				char *colon = strchr(lp+1, ':');
+				int msi, lsi, bval, actual;
+				*lp = 0;
+
+				bval = atoi(suffix+1);
+				if(colon)
+					{
+					msi = atoi(lp+1);
+					lsi = atoi(colon+1);
+	
+					if(lsi > msi)
+						{
+						actual = msi + bval;
+						}
+						else
+						{
+						actual = msi - bval;
+						}
+					}
+					else
+					{
+					actual = bval; /* punt */
+					}
+
+				sprintf(ns, "%s[%d]", suffix+i, actual);
+				*lp = '[';			
+
+				s=symfind(ns, NULL);
+				free_2(ns);
+				if(s)
+					{
+	                                lx2_set_fac_process_mask(s->n);
+	                                made = ~0;
+					}
+				}
+			}
+
 		return(made);
 		}
 	else
@@ -2990,7 +3169,7 @@ if((*w2=='#')||(*w2==':'))
 	w2=w2+strlen(prefix);
 	while(1)
 		{
-		if(isspace(*w2)) { w2++; continue; }
+		if(isspace((int)(unsigned char)*w2)) { w2++; continue; }
 		if(!(*w2)) return(0);	/* no more args */	
 		break;			/* start grabbing chars from here */
 		}
@@ -3075,8 +3254,17 @@ return(made);
 /****************/
 
 /*
- * $Id: bitvec.c,v 1.25 2010/04/04 19:09:57 gtkwave Exp $
+ * $Id: bitvec.c,v 1.28 2010/10/02 18:58:55 gtkwave Exp $
  * $Log: bitvec.c,v $
+ * Revision 1.28  2010/10/02 18:58:55  gtkwave
+ * ctype.h compiler warning fixes (char vs int)
+ *
+ * Revision 1.27  2010/07/31 20:38:38  gtkwave
+ * fix for canonical bit ordering with previous patch
+ *
+ * Revision 1.26  2010/07/31 20:00:33  gtkwave
+ * fix for cvc versus modelsim with respect to created bluespec .sav files
+ *
  * Revision 1.25  2010/04/04 19:09:57  gtkwave
  * rename name->bvname in struct BitVector for easier grep tracking
  *
@@ -3180,4 +3368,3 @@ return(made);
  * initial release
  *
  */
-
