@@ -237,7 +237,7 @@ while (1)
 			match = malloc((matchlen = 4*strlen(optarg))+1);
 			for(i=0,k=0;i<matchlen;i+=4,k++)
 				{
-				int ch = tolower(optarg[k]);
+				int ch = tolower((int)(unsigned char)optarg[k]);
 
 				if(ch=='z')
 					{
@@ -323,8 +323,11 @@ return(rc);
 }
 
 /*
- * $Id: lxt2miner.c,v 1.5 2009/04/27 21:26:34 gtkwave Exp $
+ * $Id: lxt2miner.c,v 1.6 2010/10/02 18:58:55 gtkwave Exp $
  * $Log: lxt2miner.c,v $
+ * Revision 1.6  2010/10/02 18:58:55  gtkwave
+ * ctype.h compiler warning fixes (char vs int)
+ *
  * Revision 1.5  2009/04/27 21:26:34  gtkwave
  * printf format string warning fixes
  *
