@@ -1383,24 +1383,24 @@ for(;;)
 				/* catchall for events when header over */
 				if(yytext[0]=='#')
 					{
-					TimeType time;
-					time=atoi_64(yytext+1);
+					TimeType t_time;
+					t_time=atoi_64(yytext+1);
 					
 					if(start_time<0)
 						{
-						start_time=time;
+						start_time=t_time;
 						}
 
-                                        if(time < current_time) /* avoid backtracking time counts which can happen on malformed files */
+                                        if(t_time < current_time) /* avoid backtracking time counts which can happen on malformed files */
                                                 {
-                                                time = current_time;
+                                                t_time = current_time;
                                                 }
 
-                                        current_time=time;
-                                        if(end_time<time) end_time=time;        /* in case of malformed vcd files */
+                                        current_time=t_time;
+                                        if(end_time<t_time) end_time=t_time;        /* in case of malformed vcd files */
 
 					lxt2_wr_set_time64(lt, current_time);
-					DEBUG(fprintf(stderr,"#"TTFormat"\n",time));
+					DEBUG(fprintf(stderr,"#"TTFormat"\n",t_time));
 					}
 					else
 					{
@@ -1446,7 +1446,7 @@ for(;;)
  * this function doesn't do anything useful anymore except for to mark
  * statistics on the various nets...
  */
-void add_histent(TimeType time, struct Node *n, char ch, int regadd, char *vector)
+void add_histent(TimeType t_time, struct Node *n, char ch, int regadd, char *vector)
 {
 struct HistEnt *he;
 
@@ -1461,13 +1461,13 @@ if(!n->curr)
 	n->curr=he;
 	n->head.next=he;
 
-	add_histent(time,n,ch,regadd, vector);
+	add_histent(t_time,n,ch,regadd, vector);
 	}
 	else
 	{
-	if(regadd) { time*=(time_scale); }
+	if(regadd) { t_time*=(time_scale); }
 
-	if(toupper(ch)!=deadchar) n->notdead=1;
+	if(toupper((int)(unsigned char)ch)!=deadchar) n->notdead=1;
 	n->numtrans++;
        }
 }
@@ -1484,7 +1484,7 @@ if(ch=='g')	/* real number */
 		n->curr=he;
 		n->head.next=he;
 	
-		add_histent(time,n,ch,regadd, vector);
+		add_histent(t_time,n,ch,regadd, vector);
 		}
 		else
 		{
@@ -1503,7 +1503,7 @@ if(ch=='g')	/* real number */
 		n->curr=he;
 		n->head.next=he;
 	
-		add_histent(time,n,ch,regadd, vector);
+		add_histent(t_time,n,ch,regadd, vector);
 		}
 		else
 		{
@@ -1515,7 +1515,7 @@ if(ch=='g')	/* real number */
 			n->numtrans++;
 			for(i=0;i<nlen;i++)
 				{
-				if(toupper(vector[i])!=deadchar)
+				if(toupper((int)(unsigned char)vector[i])!=deadchar)
 					{	
 					n->notdead=1;
 					return;
@@ -2010,8 +2010,14 @@ return(0);
 }
 
 /*
- * $Id: vcd2lxt2.c,v 1.10 2010/07/16 16:19:10 gtkwave Exp $
+ * $Id: vcd2lxt2.c,v 1.12 2010/10/02 19:05:51 gtkwave Exp $
  * $Log: vcd2lxt2.c,v $
+ * Revision 1.12  2010/10/02 19:05:51  gtkwave
+ * fix shadowed time variable
+ *
+ * Revision 1.11  2010/10/02 18:58:55  gtkwave
+ * ctype.h compiler warning fixes (char vs int)
+ *
  * Revision 1.10  2010/07/16 16:19:10  gtkwave
  * warning fixes
  *
