@@ -93,7 +93,7 @@ entry=GLOBALS->entries_markerbox_c_1[ent_idx];
 
 entry_text = gtk_entry_get_text(GTK_ENTRY(entry));
 if(!(len=strlen(entry_text))) goto failure;
-if(!isdigit(entry_text[0])) goto failure;
+if(!isdigit((int)(unsigned char)entry_text[0])) goto failure;
 
 temp=unformat_time(entry_text, GLOBALS->time_dimension);
 if((temp<GLOBALS->tims.start)||(temp>GLOBALS->tims.last)) goto failure;
@@ -335,8 +335,11 @@ void markerbox(char *title, GtkSignalFunc func)
 }
 
 /*
- * $Id: markerbox.c,v 1.9 2010/05/27 06:07:24 gtkwave Exp $
+ * $Id: markerbox.c,v 1.10 2010/10/02 18:58:55 gtkwave Exp $
  * $Log: markerbox.c,v $
+ * Revision 1.10  2010/10/02 18:58:55  gtkwave
+ * ctype.h compiler warning fixes (char vs int)
+ *
  * Revision 1.9  2010/05/27 06:07:24  gtkwave
  * Moved gtk_grab_add() after gtk_widget_show() as newer gtk needs that order.
  *
