@@ -35,6 +35,14 @@ GtkCTreeNode *SST_find_node_by_path(GtkCTreeRow *root, char *path) {
   GtkCTreeRow *gctr = root ;
   GtkCTreeNode *node = gctr->parent ;
   struct tree *t ;
+  /* in the cases of path that where generated inside a `generate-for' block
+   * path name will contain '[]'. This will prompt TCL to soround PATH with
+   * '{' and '}'
+   */
+  if (*p == '{' && (p1 = strrchr(p, '}'))) {
+    p++ ;
+    *p1 = '\0' ;
+  }
   while (gctr)  {
     if ((p1 = strchr(p, '.'))) 
       *p1 = '\0' ;
@@ -245,11 +253,11 @@ Trptr BitVector_to_Trptr(bvptr vec) {
   t = (Trptr) calloc_2(1, sizeof( TraceEnt ) );
   if( t == NULL ) {
     fprintf( stderr, "Out of memory, can't add %s to analyzer\n",
-	     vec->name );
+	     vec->bvname );
     return( 0 );
   }
 
-  t->name = vec->name;
+  t->name = vec->bvname;
 
   if(GLOBALS->hier_max_level)
     t->name = hier_extract(t->name, GLOBALS->hier_max_level);
@@ -287,11 +295,13 @@ Trptr is_signal_displayed(char *name) {
     *p = '\0' ;
   len = strlen(name) ;
   while(t) {
-    p = (!t->vector) ?  t->n.nd->nname : t->n.vec->name ;
-    p1 = strchr(p,'[') ;
-    len1 = (p1) ? p1 - p : strlen(p) ;
-    if((len == len1) && !strncmp(name, p, len))
-      break ;
+    if((p = (t->vector) ?  t->n.vec->bvname :
+	(t->n.vec ? t->n.nd->nname : NULL))) {
+      p1 = strchr(p,'[') ;
+      len1 = (p1) ? p1 - p : strlen(p) ;
+      if((len == len1) && !strncmp(name, p, len))
+	break ;
+    }
     t = t->t_next ;
   }
   return t ;
@@ -521,7 +531,7 @@ llist_p *signal_change_list(char *sig_name, int dir, TimeType start_time,
       if(t->n.nd->extvals) {
 	bw = abs(t->n.nd->msi - t->n.nd->lsi) + 1 ;
       }
-      h = bsearch_node(t->n.nd, tstart) ;
+      h = bsearch_node(t->n.nd, tstart - t->shift) ;
       for(h1 = h; h1; h1 = h1->next) {
 	if (h1->time <= tend) {
 	  if (len++ < max_elements) {
@@ -547,7 +557,7 @@ llist_p *signal_change_list(char *sig_name, int dir, TimeType start_time,
       }
     } else {
       vptr v, v1;
-      v = bsearch_vector(t->n.vec, tstart) ;
+      v = bsearch_vector(t->n.vec, tstart - t->shift) ;
       for(v1 = v; v1; v1 = v1->next) {
 	if (v1->time <= tend) {
 	  llist_u llp; llp.p = v1;
@@ -576,7 +586,7 @@ llist_p *signal_change_list(char *sig_name, int dir, TimeType start_time,
 	  h_ptr = (hptr)lp->u.p ;
 	  if(h_ptr->flags&HIST_REAL) {
 	    if(!(h_ptr->flags&HIST_STRING)) {
-	      s=convert_ascii_real((double *)h_ptr->v.h_vector);
+	      s=convert_ascii_real(t, (double *)h_ptr->v.h_vector);
 	    } else {
 	      s=convert_ascii_string((char *)h_ptr->v.h_vector);
 	    }
