@@ -625,11 +625,15 @@ else
 /*
  * GTK2: build the tree.
  */
-void maketree(GtkCTreeNode *subtree, struct tree *t)
+void maketree2(GtkCTreeNode *subtree, struct tree *t, int depth, GtkCTreeNode *graft)
 {
 GtkCTreeNode *sibling=NULL, *sibling_test;
 struct tree *t2;
 
+#ifndef WAVE_DISABLE_FAST_TREE
+if(depth > 1) return;
+#endif
+
 /* 
  * TG reworked treesearch widget so there is no need to 
  * process anything other than nodes.  Leaves are handled
@@ -639,20 +643,41 @@ struct tree *t2;
 t2=t;
 while(t2)
 	{
+#ifndef WAVE_DISABLE_FAST_TREE
+	if(depth < 1) 
+#endif
+		{ 
+		t2->children_in_gui = 1; 
+		}
+
 	if(t2->child)
 		{
-		sibling_test=maketree_nodes(subtree, t2, sibling, MAKETREE_NODE);
+		if(!graft)
+			{
+			sibling_test=maketree_nodes(subtree, t2, sibling, MAKETREE_NODE);
+			}
+			else
+			{
+			sibling_test = graft;
+			}
 		if(sibling_test)
 			{
 			GLOBALS->any_tree_node = sibling_test;
-			maketree(sibling=sibling_test, t2->child);
+			maketree2(sibling=sibling_test, t2->child, depth + 1, NULL);
 			}
 		}
 
+	if(graft) break;
 	t2=t2->next;
 	}
 }
 
+
+void maketree(GtkCTreeNode *subtree, struct tree *t)
+{
+maketree2(subtree, t, 0, NULL);
+}
+
 #else
 
 /*
@@ -710,8 +735,11 @@ if(!GLOBALS->hier_grouping)
 #endif
 
 /*
- * $Id: tree.c,v 1.8 2009/07/02 18:50:47 gtkwave Exp $
+ * $Id: tree.c,v 1.9 2010/09/23 22:04:55 gtkwave Exp $
  * $Log: tree.c,v $
+ * Revision 1.9  2010/09/23 22:04:55  gtkwave
+ * added incremental SST build code
+ *
  * Revision 1.8  2009/07/02 18:50:47  gtkwave
  * decorate VCD module trees with type info, add move to front to buildname
  *
