@@ -83,6 +83,12 @@ fill_sig_store (void)
   struct tree *t;
   GtkTreeIter iter;
 
+  if(GLOBALS->selected_sig_name)
+	{
+	free_2(GLOBALS->selected_sig_name);
+	GLOBALS->selected_sig_name = NULL;
+	}
+
   free_afl();
   gtk_list_store_clear (GLOBALS->sig_store_treesearch_gtk2_c_1);
 
@@ -165,6 +171,45 @@ fill_sig_store (void)
 /*
  * tree open/close handling
  */
+static void create_sst_nodes_if_necessary(GtkCTreeNode *node)
+{
+#ifndef WAVE_DISABLE_FAST_TREE
+if(node)
+	{
+	GtkCTreeRow *gctr = GTK_CTREE_ROW(node);
+	struct tree *t = (struct tree *)(gctr->row.data);
+
+	if(t->child)
+		{
+		GtkCTree *ctree = GLOBALS->ctree_main;
+		GtkCTreeNode *n = gctr->children;
+	
+		gtk_clist_freeze(GTK_CLIST(ctree));
+
+		while(n)
+			{
+			GtkCTreeRow *g = GTK_CTREE_ROW(n);
+
+			t = (struct tree *)(g->row.data);
+			if(t->which < 0)
+				{
+				if(!t->children_in_gui)
+					{
+					t->children_in_gui = 1;
+					maketree2(n, t, 0, n);
+					}
+				}
+	
+			n = GTK_CTREE_NODE_NEXT(n);
+			}
+	
+		gtk_clist_thaw(GTK_CLIST(ctree));
+		}
+	}
+#endif
+}
+
+
 int force_open_tree_node(char *name) {
   GtkCTree *ctree = GLOBALS->ctree_main;
   int rv = 1 ;			/* can possible open */
@@ -235,6 +280,7 @@ int force_open_tree_node(char *name) {
 	}
 	else {
 	  depth++;
+	  create_sst_nodes_if_necessary(node);
 	  node = gctr->children;
 	  if(!node) break;
 	  gctr = GTK_CTREE_ROW(node);
@@ -247,8 +293,7 @@ int force_open_tree_node(char *name) {
       if(!node) break;
       gctr = GTK_CTREE_ROW(node);
     }
-    
-    /* printf("[treeopennode] '%s' failed\n", name); */
+     /* printf("[treeopennode] '%s' failed\n", name); */
   } else {
     rv = -1 ;			/* tree does not exist */
   }
@@ -277,6 +322,7 @@ int depth, i;
 int len = 1;
 char *tstring;
 char hier_suffix[2];
+int found;
 
 hier_suffix[0] = GLOBALS->hier_delimeter;
 hier_suffix[1] = 0;
@@ -305,19 +351,45 @@ for(i=0;i<depth;i++)
 	strcat(tstring, hier_suffix);
 	}
 
+
+if(GLOBALS->open_tree_nodes) /* cut down on chatter to Tcl clients */
+	{
+	GLOBALS->open_tree_nodes = xl_splay(tstring, GLOBALS->open_tree_nodes);
+	if(!strcmp(GLOBALS->open_tree_nodes->item, tstring))
+		{
+		found = 1;
+		}
+		else
+		{
+		found = 0;
+		}
+	}
+	else
+	{
+	found = 0;
+	}
+
 if(is_expand)
 	{
 	GLOBALS->open_tree_nodes = xl_insert(tstring, GLOBALS->open_tree_nodes, NULL);
+	if(!found)
+		{
+		gtkwavetcl_setvar(WAVE_TCLCB_TREE_EXPAND, tstring, WAVE_TCLCB_TREE_EXPAND_FLAGS);
+		}
 	}
 	else
 	{
 	GLOBALS->open_tree_nodes = xl_delete(tstring, GLOBALS->open_tree_nodes);
+	if(found)
+		{
+		gtkwavetcl_setvar(WAVE_TCLCB_TREE_COLLAPSE, tstring, WAVE_TCLCB_TREE_COLLAPSE_FLAGS);
+		}
 	}
-
 }
 
 static void tree_expand_callback(GtkCTree *ctree, GtkCTreeNode *node, gpointer user_data)
 {
+create_sst_nodes_if_necessary(node);
 generic_tree_expand_collapse_callback(1, node);
 }
  
@@ -449,6 +521,7 @@ t=(struct tree *)gtk_clist_get_row_data(GTK_CLIST(GLOBALS->ctree_main), row);
 DEBUG(printf("TS: %08x %s\n",t,t->name));
  GLOBALS->sig_root_treesearch_gtk2_c_1 = t->child;
  fill_sig_store ();
+ gtkwavetcl_setvar(WAVE_TCLCB_TREE_SELECT, GLOBALS->selected_hierarchy_name, WAVE_TCLCB_TREE_SELECT_FLAGS);
 }
 
 static void unselect_row_callback(GtkWidget *widget, gint row, gint column,
@@ -458,6 +531,7 @@ struct tree *t;
 
 if(GLOBALS->selected_hierarchy_name)
 	{
+	gtkwavetcl_setvar(WAVE_TCLCB_TREE_UNSELECT, GLOBALS->selected_hierarchy_name, WAVE_TCLCB_TREE_UNSELECT_FLAGS);
 	free_2(GLOBALS->selected_hierarchy_name);
 	GLOBALS->selected_hierarchy_name = NULL;
 	}
@@ -1011,9 +1085,6 @@ static void destroy_callback(GtkWidget *widget, GtkWidget *nothing)
 
 /**********************************************************************/
 
-/* view_selection_func is commented out for now... */
-
-#if 0
 static gboolean
   view_selection_func (GtkTreeSelection *selection,
                        GtkTreeModel     *model,
@@ -1029,20 +1100,45 @@ static gboolean
 
       gtk_tree_model_get(model, &iter, 0, &name, -1);
 
+      if(GLOBALS->selected_sig_name)
+	{
+	free_2(GLOBALS->selected_sig_name);
+	GLOBALS->selected_sig_name = NULL;
+	}
+
       if (!path_currently_selected)
       {
-        g_print ("%s is going to be selected.\n", name);
+	GLOBALS->selected_sig_name = strdup_2(name);
+	gtkwavetcl_setvar(WAVE_TCLCB_TREE_SIG_SELECT, name, WAVE_TCLCB_TREE_SIG_SELECT_FLAGS);
       }
       else
       {
-        g_print ("%s is going to be unselected.\n", name);
+	gtkwavetcl_setvar(WAVE_TCLCB_TREE_SIG_UNSELECT, name, WAVE_TCLCB_TREE_SIG_UNSELECT_FLAGS);
       }
 
       g_free(name);
     }
     return TRUE; /* allow selection state to change */
   }
-#endif
+
+/**********************************************************************/
+
+static gint button_press_event_std(GtkWidget *widget, GdkEventButton *event)
+{
+if(event->type == GDK_2BUTTON_PRESS)
+	{
+	if(GLOBALS->selected_hierarchy_name && GLOBALS->selected_sig_name)
+		{
+		char *sstr = wave_alloca(strlen(GLOBALS->selected_hierarchy_name) + strlen(GLOBALS->selected_sig_name) + 1);
+		strcpy(sstr, GLOBALS->selected_hierarchy_name);
+		strcat(sstr, GLOBALS->selected_sig_name);
+
+		gtkwavetcl_setvar(WAVE_TCLCB_TREE_SIG_DOUBLE_CLICK, sstr, WAVE_TCLCB_TREE_SIG_DOUBLE_CLICK_FLAGS);
+		}
+	}
+
+return(FALSE);
+}
 
 /**********************************************************************/
 
@@ -1186,8 +1282,10 @@ do_tooltips:
 	/* Setup the selection handler */
 	GLOBALS->sig_selection_treesearch_gtk2_c_1 = gtk_tree_view_get_selection (GTK_TREE_VIEW (sig_view));
 	gtk_tree_selection_set_mode (GLOBALS->sig_selection_treesearch_gtk2_c_1, GTK_SELECTION_MULTIPLE);
-        /* gtk_tree_selection_set_select_function (GLOBALS->sig_selection_treesearch_gtk2_c_1,
-                                                view_selection_func, NULL, NULL); */
+        gtk_tree_selection_set_select_function (GLOBALS->sig_selection_treesearch_gtk2_c_1,
+                                                view_selection_func, NULL, NULL);
+
+	gtkwave_signal_connect(GTK_OBJECT(sig_view), "button_press_event",GTK_SIGNAL_FUNC(button_press_event_std), NULL);
       }
 
     GLOBALS->dnd_sigview = sig_view;
@@ -1437,8 +1535,10 @@ GtkWidget* treeboxframe(char *title, GtkSignalFunc func)
 	/* Setup the selection handler */
 	GLOBALS->sig_selection_treesearch_gtk2_c_1 = gtk_tree_view_get_selection (GTK_TREE_VIEW (sig_view));
 	gtk_tree_selection_set_mode (GLOBALS->sig_selection_treesearch_gtk2_c_1, GTK_SELECTION_MULTIPLE);
-        /* gtk_tree_selection_set_select_function (GLOBALS->sig_selection_treesearch_gtk2_c_1,
-                                                view_selection_func, NULL, NULL); */
+        gtk_tree_selection_set_select_function (GLOBALS->sig_selection_treesearch_gtk2_c_1,
+                                                view_selection_func, NULL, NULL);
+
+	gtkwave_signal_connect(GTK_OBJECT(sig_view), "button_press_event",GTK_SIGNAL_FUNC(button_press_event_std), NULL);
       }
 
     GLOBALS->dnd_sigview = sig_view;
@@ -2054,8 +2154,26 @@ void dnd_setup(GtkWidget *src, GtkWidget *w, int enable_receive)
 }
 
 /*
- * $Id: treesearch_gtk2.c,v 1.44 2010/05/27 06:07:25 gtkwave Exp $
+ * $Id: treesearch_gtk2.c,v 1.50 2010/09/27 18:54:31 gtkwave Exp $
  * $Log: treesearch_gtk2.c,v $
+ * Revision 1.50  2010/09/27 18:54:31  gtkwave
+ * add check for null node in dynamic sst creation
+ *
+ * Revision 1.49  2010/09/27 18:02:35  gtkwave
+ * force open tree node fix for dynamic trees
+ *
+ * Revision 1.48  2010/09/23 22:04:55  gtkwave
+ * added incremental SST build code
+ *
+ * Revision 1.47  2010/07/29 20:54:29  gtkwave
+ * add cbTreeExpand and cbTreeCollapse
+ *
+ * Revision 1.46  2010/07/28 19:18:26  gtkwave
+ * added double-click trapping via gtkwave::cbTreeSigDoubleClick
+ *
+ * Revision 1.45  2010/07/27 19:25:41  gtkwave
+ * initial tcl callback function adds
+ *
  * Revision 1.44  2010/05/27 06:07:25  gtkwave
  * Moved gtk_grab_add() after gtk_widget_show() as newer gtk needs that order.
  *
