@@ -2159,11 +2159,10 @@ while(v)
 Pvoid_t  PJArray = GLOBALS->sym_judy;
 PPvoid_t PPValue;
 char *Index = calloc_2(1, longest);
-JError_t JError;
                                         
-for (PPValue  = JudySLFirst (PJArray, (uint8_t *)Index, &JError);
+for (PPValue  = JudySLFirst (PJArray, (uint8_t *)Index, PJE0);
          PPValue != (PPvoid_t) NULL;
-         PPValue  = JudySLNext  (PJArray, (uint8_t *)Index, &JError))
+         PPValue  = JudySLNext  (PJArray, (uint8_t *)Index, PJE0))
     {                   
         struct symbol *s = *(struct symbol **)PPValue;  
         s->name = strdup_2(Index);
@@ -2531,8 +2530,11 @@ gtkwave_main_iteration();
 }
 
 /*
- * $Id: vcd_partial.c,v 1.36 2010/06/02 03:51:30 gtkwave Exp $
+ * $Id: vcd_partial.c,v 1.37 2010/11/19 06:47:16 gtkwave Exp $
  * $Log: vcd_partial.c,v $
+ * Revision 1.37  2010/11/19 06:47:16  gtkwave
+ * use PJE0 macro for unuser error return on judy function calls
+ *
  * Revision 1.36  2010/06/02 03:51:30  gtkwave
  * don't autocoalesce escape identifiers
  *
