@@ -2514,11 +2514,10 @@ while(v)
 Pvoid_t  PJArray = GLOBALS->sym_judy;
 PPvoid_t PPValue;
 char *Index = calloc_2(1, longest);
-JError_t JError;  
 
-for (PPValue  = JudySLFirst (PJArray, (uint8_t *)Index, &JError);
+for (PPValue  = JudySLFirst (PJArray, (uint8_t *)Index, PJE0);
          PPValue != (PPvoid_t) NULL;
-         PPValue  = JudySLNext  (PJArray, (uint8_t *)Index, &JError))
+         PPValue  = JudySLNext  (PJArray, (uint8_t *)Index, PJE0))
     {        
 	struct symbol *s = *(struct symbol **)PPValue;
 	s->name = strdup_2(Index);
@@ -3234,8 +3233,11 @@ np->mv.mvlfac_vlist = NULL;
 }
 
 /*
- * $Id: vcd_recoder.c,v 1.46 2010/11/07 16:20:33 gtkwave Exp $
+ * $Id: vcd_recoder.c,v 1.47 2010/11/19 06:47:16 gtkwave Exp $
  * $Log: vcd_recoder.c,v $
+ * Revision 1.47  2010/11/19 06:47:16  gtkwave
+ * use PJE0 macro for unuser error return on judy function calls
+ *
  * Revision 1.46  2010/11/07 16:20:33  gtkwave
  * make fst the default file format for --optimize action in gtkwave
  *
